# Generated by Django 2.0rc1 on 2017-11-28 14:41

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import jsonfield.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='OpenIDClient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('client_id', models.CharField(max_length=128, unique=True)),
                ('redirect_uris', models.TextField(default='')),
                ('client_auth_type', models.CharField(choices=[('basic', 'Basic Authentication'), ('post', 'Authentication data in POST request'), ('sjwt', 'JSON Web token with pre-shared secret'), ('pkjwt', 'JSON Web token with public/private key'), ('none', 'No client authentication performed')], max_length=8)),
                ('client_hashed_secret', models.CharField(max_length=128)),
                ('client_name', models.CharField(max_length=128)),
            ],
        ),
        migrations.CreateModel(
            name='OpenIDToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token_hash', models.CharField(max_length=64, unique=True)),
                ('token_type', models.CharField(max_length=4)),
                ('token_data', jsonfield.fields.JSONField(default={})),
                ('expiration', models.DateTimeField()),
                ('client', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='openid_connect_op.OpenIDClient')),
                ('root_token', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='related_tokens', to='openid_connect_op.OpenIDToken')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



# Generated by Django 2.0rc1 on 2017-11-29 09:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0002_openidclient_keys'),
    ]

    operations = [
        migrations.CreateModel(
            name='OpenIDKey',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key_type', models.CharField(choices=[('jwk_rsa_private', 'JWK RSA private key'), ('jwk_rsa_public', 'JWK RSA public key'), ('aes', 'AES key')], max_length=16)),
                ('encrypted_key_value', models.BinaryField()),
            ],
        ),
        migrations.RemoveField(
            model_name='openidclient',
            name='keys',
        ),
        migrations.AddField(
            model_name='openidkey',
            name='client',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='openid_connect_op.OpenIDClient'),
        ),
    ]



# Generated by Django 2.0rc1 on 2017-11-29 08:58

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='keys',
            field=jsonfield.fields.JSONField(default={}),
        ),
    ]



# Generated by Django 2.0rc1 on 2017-11-30 09:56

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('openid_connect_op', '0003_auto_20171129_0339'),
    ]

    operations = [
        migrations.AddField(
            model_name='openidclient',
            name='allowed_claims',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='List of allowed claims. If None, all claims from allowed scopes are returned'),
        ),
        migrations.AddField(
            model_name='openidclient',
            name='allowed_scopes',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='List of allowed scopes. If None, all scopes are allowed'),
        ),
    ]



from django.conf.urls import include, url

from tests.views import ConsentView, IndexView

urlpatterns = [
    url('^django/', include('django.contrib.auth.urls')),
    url('^', include('openid_connect_op.urls')),
    url('', include('social_django.urls', namespace='social')),
    # test views
    url('', include(
        (
            [
                url(r'^openid/consent/(?P<client_id>\d+)/', ConsentView.as_view(), name='consent'),
                url(r'^', IndexView.as_view()),
            ],
            'test'
        ), namespace='test'))
]
